# -*- coding: utf-8 -*-
import serial

class SerialTranceiver():
    BAUDRATE = 115200

    def __init__(self, device, *, eol=b'\x0a', timeout_rw=None):
        self.ser = serial.Serial(device, self.BAUDRATE, timeout=timeout_rw, write_timeout=timeout_rw)
        self.eol = eol

    def close(self):
        self.ser.close()

    def readline(self, size=None):
        leneol = len(self.eol)
        line = bytearray()
        while True:
            c = self.ser.read(1)
            if c:
                line += c
                if line[-leneol:] == self.eol:
                    break
                if size is not None and len(line) >= size:
                    break
            else:
                raise TimeoutError("Timeout on {0}".format(self.ser.port))
        return bytes(line)

    def write(self, data):
        b = bytearray()
        b.append(data)
        self.ser.write(b)

    def write_string(self, data):
        self.ser.write(data)

    def write_eol(self):
        self.ser.write(self.eol)

    def getc(self, size, timeout=1):
        return self.ser.read(size) or None

    def putc(self, data, timeout=1):
        return self.ser.write(data)

    def in_waiting(self):
        return self.ser.in_waiting

if __name__ == '__main__':
    # device = '/dev/ttyUSB0'    # Linux
    device = 'com8'    # Windows
    serial = SerialTranceiver(device)
    print('start')
    stx = 0x02
    command = b'COOFF1'
    etx = 0x03
    eot = 0x04
    ckcode1 = 0x36
    ckcode2 = 0x32
    # COOFF1を送信する
    serial.write(stx)
    serial.write_string(command)
    serial.write(etx)
    serial.write(ckcode1)
    serial.write(ckcode2)
    serial.write(eot)
    serial.write_lf()
